Module: Authlogic::Session::ActiveRecordTrickery::InstanceMethods

Defined in:
lib/authlogic/session/active_record_trickery.rb

Instance Method Summary collapse

Instance Method Details

#new_record? ⇒ Boolean

Don't use this yourself, this is to just trick some of the helpers since this is the method it calls.



44
45
46
# File 'lib/authlogic/session/active_record_trickery.rb', line 44

def new_record?
  new_session?
end